# Logto Python SDK

Still work in progress.

## Usage

### Installation
```bash
pip install logto
```

### Sample code

See `samples/` directory for example usages.

### Documentation

While the dedicated documentation is still in progress, you can find other integration guides in [Integrate Logto in your application](https://docs.logto.io/docs/recipes/integrate-logto/).

Pick one you are most familiar with, read to know the basic concepts, then come back and check out `samples/` directory for example usages.
